==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Output/shout/translations/shout_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>OutputShoutFactory</name>
    <message>
        <location filename="../outputshoutfactory.cpp" line="40"/>
        <source>Icecast Plugin</source>
        <translation>Wtyczka Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="65"/>
        <source>About Icecast Output Plugin</source>
        <translation>O wtyczce wyjściowej Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="66"/>
        <source>Qmmp Icecast Output Plugin</source>
        <translation>Wtyczka wyjściowa Icecast dla Qmmp</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="67"/>
        <source>Compiled against libshout-%1</source>
        <translation>Skompilowana z biblioteką libshout-%1</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="68"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Connection Settings</source>
        <translation>Ustawienia połączenia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <source>Mount point:</source>
        <translation>Punkt montowania:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Quality:</source>
        <translation>Jakość:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Sample rate:</source>
        <translation>Próbkowanie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Public</source>
        <translation>Publiczny</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Output/shout/translations/shout_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>OutputShoutFactory</name>
    <message>
        <location filename="../outputshoutfactory.cpp" line="40"/>
        <source>Icecast Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="65"/>
        <source>About Icecast Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="66"/>
        <source>Qmmp Icecast Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="67"/>
        <source>Compiled against libshout-%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="68"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <source>Mount point:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Sample rate:</source>
        <translation>Próbkowanie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Public</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
</context>
</TS>
